Learn R Programming

pacman (version 0.5.1)

p_delete: Permanently Remove Package Removal(s) From Library

Description

Remove package(s) from the library permanently.

Usage

p_delete(..., char, character.only = FALSE, quiet = FALSE)

p_del(..., char, character.only = FALSE, quiet = FALSE)

Arguments

char

Character vector containing packages to load. If you are calling p_delete from within a function (or just having difficulties calling it using a character vector input) then pass your character vector of packages to load to this parameter directly.

character.only

logical. If TRUE then p_load will only accept a single input which is a character vector containing the names of packages to load.

quiet

logical. Passed to print.p_delete as an attribute. If TRUE no messages confirming package deletions are printed.

…

name(s) of package(s).

Warning

Using this function will remove the package from your library and cannot be loaded again without reinstalling the package.

See Also

remove.packages

Examples

Run this code
# NOT RUN {
p_delete(pacman) # You never want to run this
# }

Run the code above in your browser using DataLab